@@ -1,9 +1,12 @@
 import sys
 
 __project__ = "spacy_api"
-__version__ = "0.0.15"
+__version__ = "0.2.19"
 __repo__ = "https://github.com/kootenpv/spacy_api"
 
+from spacy_api.client import Connector
+from spacy_api.server import SpacyLocalServer as LocalConnector
+
 
 def print_version():
     sv = sys.version_info
